@@ -89,7 +89,7 @@ bool compare_prefix_dir( const char * const dir, const char * const name )
   {
   int len = 0;
   while( dir[len] && dir[len] == name[len] ) ++len;
-  return ( !dir[len] && len > 0 && ( dir[len-1] == '/' || name[len] == '/' ) );
+  return !dir[len] && len > 0 && ( dir[len-1] == '/' || name[len] == '/' );
   }
 
 
@@ -101,7 +101,7 @@ bool compare_tslash( const char * const name1, const char * const name2 )
   while( *p && *p == *q ) { ++p; ++q; }
   while( *p == '/' ) ++p;
   while( *q == '/' ) ++q;
-  return ( !*p && !*q );
+  return !*p && !*q;
   }
 
 } // end namespace
@@ -129,7 +129,7 @@ bool format_member_name( const Extended & extended, const Tar_header header,
       { time_t z = 0; if( !gmtime_r( &z, &t ) )		// use UTC, the epoch
         { t.tm_year = 70; t.tm_mon = t.tm_hour = t.tm_min = 0; t.tm_mday = 1; } }
     const Typeflag typeflag = (Typeflag)header[typeflag_o];
-    const bool islink = ( typeflag == tf_link || typeflag == tf_symlink );
+    const bool islink = typeflag == tf_link || typeflag == tf_symlink;
     const char * const link_string = !islink ? "" :
                          ( ( typeflag == tf_link ) ? " link to " : " -> " );
     // print "user/group size" in a field of width 19 with 8 or more for size
