@@ -34,6 +34,7 @@ in_tar="${testdir}"/test.txt.tar
 in_tar_lz="${testdir}"/test.txt.tar.lz
 inbad1="${testdir}"/test_bad1.txt
 inbad2="${testdir}"/test_bad2.txt
+em_lz="${testdir}"/em.lz
 test3="${testdir}"/test3.tar
 test3_lz="${testdir}"/test3.tar.lz
 test3dir="${testdir}"/test3_dir.tar
@@ -76,8 +77,8 @@ cyg_symlink() { [ ${lwarnc} = 0 ] &&
 # tar_in_tlz1.tar.lz: 2 members (test.txt.tar test3.tar) 3 lzip members
 # tar_in_tlz2.tar.lz: 2 members (test.txt.tar test3.tar) 5 lzip members
 # ts_in_link.tar.lz: 4 symbolic links (link[1-4]) to / /dir/ dir/ dir(107/)
-# test_bad1.txt.tar.lz: truncated at offset 6000 (of 7495)
-# test_bad2.txt.tar.lz: byte at offset 6000 changed from 0x56 to 0x46
+# test_bad1.txt.tar.lz: truncated at offset 6000 (of 7459)
+# test_bad2.txt.tar.lz: byte at offset 6000 changed from 0x53 to 0x43
 # test3.tar[.lz]:    3 members (foo bar baz) + 2 zeroed 512-byte blocks
 # test3_dir.tar[.lz] like test3.tar but members /dir/foo /dir/bar /dir/baz
 # test3_dot.tar.lz:  3 times 3 members ./foo ././bar ./././baz
@@ -100,8 +101,6 @@ cyg_symlink() { [ ${lwarnc} = 0 ] &&
 # test3_eoa3.tar.lz: test3.tar.lz with one zeroed block between foo and bar
 # test3_eoa4.tar.lz: test3.tar.lz ended by extended header without EOA blocks
 # test3_eoa5.tar.lz: test3.tar.lz split extended bar member, without EOA blocks
-# test3_em?.tar.lz:  test3.tar.lz with one empty lzip member at each position
-# test3_em6.tar.lz:  test3.tar.lz preceded by four empty lzip members
 # test3_gh?.tar:     test3.tar with global header at each position
 # test3_gh?.tar.lz:  test3.tar.lz with global before bar split in 4 ways
 # test3_gh5.tar.lz:  test3.tar.lz with global in lzip member before foo
@@ -235,9 +234,9 @@ done
 rm -f out || framework_failure
 
 # test3 reference files for cmp
-cat "${testdir}"/rfoo > cfoo || framework_failure
-cat "${testdir}"/rbar > cbar || framework_failure
-cat "${testdir}"/rbaz > cbaz || framework_failure
+cp "${testdir}"/rfoo cfoo || framework_failure
+cp "${testdir}"/rbar cbar || framework_failure
+cp "${testdir}"/rbaz cbaz || framework_failure
 
 # test --list and --extract test3
 rm -f foo bar baz || framework_failure
@@ -492,9 +491,26 @@ for i in gh1 gh2 gh3 gh4 ; do
   rm -f foo bar baz out || framework_failure
 done
 
-# test --list and --extract with empty lzip members, global headers and
-# extended tar members split among lzip members
-for i in em1 em2 em3 em4 em5 em6 gh1 gh2 gh3 gh4 gh5 gh6 sm1 sm2 sm3 sm4 ; do
+# test --list and --extract with empty lzip member
+cat "${em_lz}" "${test3_lz}" > test3_em.tar.lz || framework_failure
+"${TARLZ}" -q -tf test3_em.tar.lz > out
+[ $? = 2 ] || test_failed $LINENO
+"${TARLZ}" -tvf - < test3_em.tar.lz > out || test_failed $LINENO
+diff -u vlist3 out || test_failed $LINENO
+"${TARLZ}" -q -xf test3_em.tar.lz
+[ $? = 2 ] || test_failed $LINENO
+[ ! -e foo ] || test_failed $LINENO
+[ ! -e bar ] || test_failed $LINENO
+[ ! -e baz ] || test_failed $LINENO
+"${TARLZ}" -xf - < test3_em.tar.lz || test_failed $LINENO
+cmp cfoo foo || test_failed $LINENO
+cmp cbar bar || test_failed $LINENO
+cmp cbaz baz || test_failed $LINENO
+rm -f foo bar baz || framework_failure
+
+# test --list and --extract with global headers and extended tar members
+# split among lzip members
+for i in gh1 gh2 gh3 gh4 gh5 gh6 sm1 sm2 sm3 sm4 ; do
 	for j in 0 2 6 ; do
 		"${TARLZ}" -n$j -tf "${testdir}"/test3_${i}.tar.lz > out ||
 			test_failed $LINENO "$i $j"
@@ -518,14 +534,14 @@ rm -f list3 vlist3 || framework_failure
 printf "\ntesting --concatenate..."
 
 # test --concatenate compressed
-cat "${in}" > out.tar.lz || framework_failure		# invalid tar.lz
+cp "${in}" out.tar.lz || framework_failure		# invalid tar.lz
 "${TARLZ}" -Aqf out.tar.lz "${test3_lz}"
 [ $? = 2 ] || test_failed $LINENO
-cat "${in_tar_lz}" > out.tar.lz || framework_failure
+cp "${in_tar_lz}" out.tar.lz || framework_failure
 "${TARLZ}" -q --un -Af out.tar.lz "${test3_lz}"		# contradictory ext
 [ $? = 1 ] || test_failed $LINENO
 cmp "${in_tar_lz}" out.tar.lz || test_failed $LINENO
-cat "${in_tar_lz}" > out.tar.lz || framework_failure
+cp "${in_tar_lz}" out.tar.lz || framework_failure
 "${TARLZ}" -Af out.tar.lz "${test3_lz}" || test_failed $LINENO
 "${TARLZ}" -xf out.tar.lz || test_failed $LINENO
 cmp "${in}" test.txt || test_failed $LINENO
@@ -547,12 +563,12 @@ cmp out.tar.lz aout.tar.lz || test_failed $LINENO
 cmp "${in_tar_lz}" aout.tar.lz || test_failed $LINENO
 "${TARLZ}" -A "${in_tar_lz}" "${test3_lz}" > aout.tar.lz || test_failed $LINENO
 cmp out.tar.lz aout.tar.lz || test_failed $LINENO
-cat "${eoa_lz}" > aout.tar.lz || framework_failure
+cp "${eoa_lz}" aout.tar.lz || framework_failure
 "${TARLZ}" -Aqf aout.tar.lz "${in_tar}"		# concatenate to empty archive
 [ $? = 2 ] || test_failed $LINENO
 "${TARLZ}" -Af aout.tar.lz "${in_tar_lz}" "${test3_lz}" || test_failed $LINENO
 cmp out.tar.lz aout.tar.lz || test_failed $LINENO
-cat "${in_tar_lz}" > aout.tar.lz || framework_failure
+cp "${in_tar_lz}" aout.tar.lz || framework_failure
 "${TARLZ}" -Aqf aout.tar.lz "${test3_lz}" "${test3}"
 [ $? = 2 ] || test_failed $LINENO
 cmp out.tar.lz aout.tar.lz || test_failed $LINENO
@@ -566,14 +582,14 @@ cmp out.tar.lz aout.tar.lz || test_failed $LINENO
 rm -f out.tar.lz aout.tar.lz || framework_failure
 
 # test --concatenate uncompressed
-cat "${in}" > out.tar || framework_failure		# invalid tar
+cp "${in}" out.tar || framework_failure		# invalid tar
 "${TARLZ}" -Aqf out.tar "${test3}"
 [ $? = 2 ] || test_failed $LINENO
-cat "${in_tar}" > out.tar || framework_failure
+cp "${in_tar}" out.tar || framework_failure
 "${TARLZ}" -q -0 -Af out.tar "${test3}"			# contradictory ext
 [ $? = 1 ] || test_failed $LINENO
 cmp "${in_tar}" out.tar || test_failed $LINENO
-cat "${in_tar}" > out.tar || framework_failure
+cp "${in_tar}" out.tar || framework_failure
 "${TARLZ}" -Af out.tar "${test3}" || test_failed $LINENO
 "${TARLZ}" -xf out.tar || test_failed $LINENO
 cmp "${in}" test.txt || test_failed $LINENO
@@ -595,12 +611,12 @@ cmp out.tar aout.tar || test_failed $LINENO
 cmp "${in_tar}" aout.tar || test_failed $LINENO
 "${TARLZ}" -A "${in_tar}" "${test3}" > aout.tar || test_failed $LINENO
 cmp out.tar aout.tar || test_failed $LINENO
-cat "${eoa}" > aout.tar || framework_failure	# concatenate to empty archive
+cp "${eoa}" aout.tar || framework_failure	# concatenate to empty archive
 "${TARLZ}" -Aqf aout.tar "${in_tar_lz}"
 [ $? = 2 ] || test_failed $LINENO
 "${TARLZ}" -Af aout.tar "${in_tar}" "${test3}" || test_failed $LINENO
 cmp out.tar aout.tar || test_failed $LINENO
-cat "${in_tar}" > aout.tar || framework_failure
+cp "${in_tar}" aout.tar || framework_failure
 "${TARLZ}" -Aqf aout.tar "${test3}" "${test3_lz}"
 [ $? = 2 ] || test_failed $LINENO
 cmp out.tar aout.tar || test_failed $LINENO
@@ -616,13 +632,13 @@ rm -f out.tar aout.tar || framework_failure
 printf "\ntesting --create..."
 
 # test --create
-cat "${in}" > test.txt || framework_failure
+cp "${in}" test.txt || framework_failure
 "${TARLZ}" --warn-newer -0 -cf out.tar.lz test.txt || test_failed $LINENO
 is_compressed out.tar.lz || test_failed $LINENO
 rm -f test.txt || framework_failure
 "${TARLZ}" -xf out.tar.lz --missing-crc || test_failed $LINENO
 cmp "${in}" test.txt || test_failed $LINENO
-cat "${in}" > test.txt || framework_failure
+cp "${in}" test.txt || framework_failure
 "${TARLZ}" --warn-newer --un -cf out.tar test.txt || test_failed $LINENO
 is_uncompressed out.tar || test_failed $LINENO
 rm -f test.txt || framework_failure
@@ -630,9 +646,9 @@ rm -f test.txt || framework_failure
 cmp "${in}" test.txt || test_failed $LINENO
 rm -f test.txt out.tar out.tar.lz || framework_failure
 
-cat cfoo > foo || framework_failure
+cp cfoo foo || framework_failure
 rm -f bar || framework_failure
-cat cbaz > baz || framework_failure
+cp cbaz baz || framework_failure
 "${TARLZ}" -0 -q -cf out.tar.lz foo bar baz
 [ $? = 1 ] || test_failed $LINENO
 rm -f foo bar baz || framework_failure
@@ -648,9 +664,9 @@ rm -f foo bar baz || framework_failure
 [ ! -e baz ] || test_failed $LINENO
 rm -f out.tar.lz || framework_failure
 
-cat cfoo > foo || framework_failure
-cat cbar > bar || framework_failure
-cat cbaz > baz || framework_failure
+cp cfoo foo || framework_failure
+cp cbar bar || framework_failure
+cp cbaz baz || framework_failure
 "${TARLZ}" -0 -cf out.tar.lz foo bar baz --out-slots=1 || test_failed $LINENO
 "${TARLZ}" -0 -q -cf aout.tar.lz foo bar aout.tar.lz baz || test_failed $LINENO
 cmp out.tar.lz aout.tar.lz || test_failed $LINENO	# test reproducible
@@ -709,9 +725,9 @@ rm -rf dir1 || framework_failure
 rm -f out.tar.lz aout.tar.lz || framework_failure
 
 # test --create --exclude
-cat cfoo > foo || framework_failure
-cat cbar > bar || framework_failure
-cat cbaz > baz || framework_failure
+cp cfoo foo || framework_failure
+cp cbar bar || framework_failure
+cp cbaz baz || framework_failure
 "${TARLZ}" -0 -cf out.tar.lz foo bar baz --exclude 'ba?' || test_failed $LINENO
 rm -f foo bar baz || framework_failure
 "${TARLZ}" -xf out.tar.lz || test_failed $LINENO
@@ -719,9 +735,9 @@ cmp cfoo foo || test_failed $LINENO
 [ ! -e bar ] || test_failed $LINENO
 [ ! -e baz ] || test_failed $LINENO
 rm -f out.tar.lz foo bar baz || framework_failure
-cat cfoo > foo || framework_failure
-cat cbar > bar || framework_failure
-cat cbaz > baz || framework_failure
+cp cfoo foo || framework_failure
+cp cbar bar || framework_failure
+cp cbaz baz || framework_failure
 "${TARLZ}" -cf out.tar foo bar baz --exclude 'ba*' || test_failed $LINENO
 is_uncompressed out.tar || test_failed $LINENO
 rm -f foo bar baz || framework_failure
@@ -746,9 +762,14 @@ dates='@-9223372036854775808 @-9223372036854775807
        2242-03-16T12:56:31 2242-03-16T12:56:32 @8589934591 @8589934592
        9999-12-31T23:59:58 9999-12-31T23:59:59
        2147483647-12-31T23:59:59 @9223372036854775807'
-touch -d 2022-01-05T12:22:13 bar || framework_failure
+touch -d 2022-01-05T12:22:13 bar >/dev/null 2>&1 ||
+touch -d '2022-01-05 12:22:13' bar >/dev/null 2>&1 ||
+touch bar || framework_failure
 for i in ${dates} @-8Ei '2017-10-01 09:00:00' '2017-10-1 9:0:0' \
          '2017-10-01 09:00' '2017-10-01 09' 2017-10-01 ./bar ; do
+  # Skip a time stamp $i if it's out of range for this platform,
+  # or if it uses a notation that this platform does not recognize.
+  [ "$i" = "./bar" ] || touch -d "$i" foo >/dev/null 2>&1 || continue
   touch foo || framework_failure
   "${TARLZ}" -cf out.tar --mtime="$i" foo || test_failed $LINENO "$i"
   is_uncompressed out.tar || test_failed $LINENO "$i"
@@ -761,11 +782,7 @@ done
 rm -f out.tar foo bar || framework_failure
 
 mkdir dir || framework_failure
-for i in ${dates} ; do
-  # Skip a time stamp $i if it's out of range for this platform,
-  # of if it uses a notation that this platform does not recognize.
-  touch -d "$i" "dir/f$i" >/dev/null 2>&1 || continue
-done
+for i in ${dates} ; do touch -d "$i" "dir/f$i" >/dev/null 2>&1 ; done
 "${TARLZ}" -cf out.tar dir || test_failed $LINENO
 is_uncompressed out.tar || test_failed $LINENO
 "${TARLZ}" -df out.tar || test_failed $LINENO
@@ -814,14 +831,14 @@ rm -f out.tar aout.tar foo bar baz || framework_failure
 printf "\ntesting --delete..."
 
 # test --delete
-cat "${in}" > out.tar || framework_failure		# invalid tar
+cp "${in}" out.tar || framework_failure		# invalid tar
 "${TARLZ}" -q -f out.tar --delete foo
 [ $? = 2 ] || test_failed $LINENO
 rm -f out.tar || framework_failure
-cat "${in}" > out.tar.lz || framework_failure		# invalid tar.lz
+cp "${in}" out.tar.lz || framework_failure		# invalid tar.lz
 "${TARLZ}" -q -f out.tar.lz --delete foo
 [ $? = 2 ] || test_failed $LINENO
-cat "${in_lz}" > out.tar.lz || framework_failure	# invalid tar.lz
+cp "${in_lz}" out.tar.lz || framework_failure		# invalid tar.lz
 "${TARLZ}" -q -f out.tar.lz --delete foo
 [ $? = 2 ] || test_failed $LINENO
 rm -f out.tar.lz || framework_failure
@@ -881,10 +898,10 @@ for e in "" .lz ; do
 done
 
 # test --delete individual member after collective member
-cat cfoo > foo || framework_failure
-cat cbar > bar || framework_failure
-cat cbaz > baz || framework_failure
-cat "${in}" > test.txt || framework_failure
+cp cfoo foo || framework_failure
+cp cbar bar || framework_failure
+cp cbaz baz || framework_failure
+cp "${in}" test.txt || framework_failure
 "${TARLZ}" -0 -cf out.tar.lz foo bar baz --asolid || test_failed $LINENO
 "${TARLZ}" -0 -rf out.tar.lz test.txt || test_failed $LINENO
 rm -f foo bar baz test.txt || framework_failure
@@ -901,20 +918,16 @@ cmp cbaz baz || test_failed $LINENO
 rm -f out.tar.lz foo bar baz test.txt || framework_failure
 
 # test --delete with empty lzip member, global header
-for i in 1 2 3 4 5 6 ; do
-  cat "${testdir}"/test3_em${i}.tar.lz > out.tar.lz || framework_failure
-  for j in foo bar baz ; do
-    "${TARLZ}" -f out.tar.lz --delete $j || test_failed $LINENO "$i $j"
-  done
-  rm -f out.tar.lz || framework_failure
-done
-cat "${testdir}"/test3_gh5.tar.lz > out.tar.lz || framework_failure
+"${TARLZ}" -q -f test3_em.tar.lz --delete foo
+[ $? = 2 ] || test_failed $LINENO
+rm -f test3_em.tar.lz || framework_failure
+cp "${testdir}"/test3_gh5.tar.lz out.tar.lz || framework_failure
 for i in foo bar baz ; do
 	"${TARLZ}" -f out.tar.lz --delete $i || test_failed $LINENO $i
 done
 rm -f out.tar.lz || framework_failure
 for i in 1 2 3 4 ; do
-	cat "${testdir}"/test3_gh${i}.tar > out.tar || framework_failure
+	cp "${testdir}"/test3_gh${i}.tar out.tar || framework_failure
 	for j in foo bar baz ; do
 		"${TARLZ}" -f out.tar --delete $j || test_failed $LINENO "$i $j"
 	done
@@ -935,9 +948,9 @@ rm -f dummy_slink dummy_link dummy_file || framework_failure
 #
 if [ "${ln_works}" = yes ] ; then
 	mkdir dir || framework_failure
-	cat cfoo > dir/foo || framework_failure
-	cat cbar > dir/bar || framework_failure
-	cat cbaz > dir/baz || framework_failure
+	cp cfoo dir/foo || framework_failure
+	cp cbar dir/bar || framework_failure
+	cp cbaz dir/baz || framework_failure
 	ln -s dir dir_link || framework_failure
 	"${TARLZ}" -0 -c dir_link > out1 || test_failed $LINENO
 	is_compressed out1 || test_failed $LINENO
@@ -968,9 +981,9 @@ fi
 printf "\ntesting --append..."
 
 # test --append compressed
-cat cfoo > foo || framework_failure
-cat cbar > bar || framework_failure
-cat cbaz > baz || framework_failure
+cp cfoo foo || framework_failure
+cp cbar bar || framework_failure
+cp cbaz baz || framework_failure
 "${TARLZ}" -0 -cf out.tar.lz foo bar baz --out-slots=1024 || test_failed $LINENO
 "${TARLZ}" -0 -cf nout.tar.lz foo bar baz --no-solid || test_failed $LINENO
 "${TARLZ}" -0 -cf aout.tar.lz foo || test_failed $LINENO
@@ -994,7 +1007,7 @@ cmp out.tar.lz aout.tar.lz || test_failed $LINENO
 "${TARLZ}" --un -q -rf aout.tar.lz foo bar baz		# contradictory ext
 [ $? = 1 ] || test_failed $LINENO
 cmp out.tar.lz aout.tar.lz || test_failed $LINENO
-cat "${eoa_lz}" > aout.tar.lz || framework_failure  # append to empty archive
+cp "${eoa_lz}" aout.tar.lz || framework_failure  # append to empty archive
 "${TARLZ}" -0 -rf aout.tar.lz foo bar baz || test_failed $LINENO
 cmp out.tar.lz aout.tar.lz || test_failed $LINENO
 rm -f out.tar.lz aout.tar.lz || framework_failure
@@ -1028,7 +1041,7 @@ cmp out.tar aout.tar || test_failed $LINENO
 "${TARLZ}" -0 -q -rf aout.tar foo bar baz		# contradictory ext
 [ $? = 1 ] || test_failed $LINENO
 cmp out.tar aout.tar || test_failed $LINENO
-cat "${eoa}" > aout.tar || framework_failure	# append to empty archive
+cp "${eoa}" aout.tar || framework_failure	# append to empty archive
 "${TARLZ}" -rf aout.tar foo bar baz || test_failed $LINENO
 cmp out.tar aout.tar || test_failed $LINENO
 rm -f out.tar aout.tar || framework_failure
@@ -1036,7 +1049,7 @@ rm -f out.tar aout.tar || framework_failure
 # test --append to solid archive
 "${TARLZ}" --solid -q -0 -cf out.tar.lz "${in}" foo bar || test_failed $LINENO
 "${TARLZ}" -q -tf out.tar.lz || test_failed $LINENO	# compressed seekable
-cat out.tar.lz > aout.tar.lz || framework_failure
+cp out.tar.lz aout.tar.lz || framework_failure
 for i in --asolid --bsolid --dsolid --solid -0 ; do
 	"${TARLZ}" $i -q -rf out.tar.lz baz
 	[ $? = 2 ] || test_failed $LINENO $i
@@ -1083,7 +1096,7 @@ if [ "${ln_works}" = yes ] ; then
 	mkdir dir1 || framework_failure
 	mkdir dir1/dir2 || framework_failure
 	mkdir dir1/dir2/dir3 || framework_failure
-	cat "${in}" > dir1/dir2/dir3/in || framework_failure
+	cp "${in}" dir1/dir2/dir3/in || framework_failure
 	ln dir1/dir2/dir3/in dir1/dir2/dir3/"${name_100}" || framework_failure
 	ln dir1/dir2/dir3/in "${path_100}" || framework_failure
 	ln dir1/dir2/dir3/in "${path_106}" || framework_failure
@@ -1160,20 +1173,20 @@ rm -f foo || framework_failure
 
 printf "\ntesting --compress..."
 
-cat cfoo > foo || framework_failure
-cat cbar > bar || framework_failure
-cat cbaz > baz || framework_failure
-cat "${in}" > test.txt || framework_failure
+cp cfoo foo || framework_failure
+cp cbar bar || framework_failure
+cp cbaz baz || framework_failure
+cp "${in}" test.txt || framework_failure
 "${TARLZ}" -cf out.tar test.txt foo bar baz test.txt || test_failed $LINENO
 "${TARLZ}" -cf out3.tar foo bar baz || test_failed $LINENO
-cat out.tar > outz.tar || framework_failure
-cat out3.tar > out3z.tar || framework_failure
+cp out.tar outz.tar || framework_failure
+cp out3.tar out3z.tar || framework_failure
 #
 "${TARLZ}" -0 -z outz.tar out3z.tar || test_failed $LINENO
 "${TARLZ}" -q -tf outz.tar.lz || test_failed $LINENO
 "${TARLZ}" -q -tf out3z.tar.lz || test_failed $LINENO
-cat outz.tar.lz > out || test_failed $LINENO
-cat out3z.tar.lz > out3 || test_failed $LINENO
+cp outz.tar.lz out || test_failed $LINENO
+cp out3z.tar.lz out3 || test_failed $LINENO
 rm -f out3z.tar.lz || framework_failure
 "${TARLZ}" -q -0 -z outz.tar out3z.tar		# outz.tar.lz exists
 [ $? = 1 ] || test_failed $LINENO
@@ -1271,7 +1284,7 @@ rm -f truncated.tar || framework_failure
 
 # test --delete with split 'bar' tar member
 for i in 1 2 3 4 ; do
-  cat "${testdir}"/test3_sm${i}.tar.lz > out.tar.lz || framework_failure
+  cp "${testdir}"/test3_sm${i}.tar.lz out.tar.lz || framework_failure
   for j in bar baz ; do
     "${TARLZ}" -q -f out.tar.lz --delete $j
     [ $? = 2 ] || test_failed $LINENO "$i $j"
